==> vaadin-jmxconfiggenerator-20.0.0-20170418.065824-153-sources.jar: org/opennms/features/vaadin/jmxconfiggenerator/ui/mbeans/validation/NameValidator.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2011-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.vaadin.jmxconfiggenerator.ui.mbeans.validation;

import com.vaadin.data.validator.RegexpValidator;

/**
 *
 * @author Markus von Rüden
 */
public class NameValidator extends RegexpValidator {

	protected static final String ERROR_MESSAGE = "You must specify a valid name. Allowed characters: (a-z, A-Z, 0-9,. , _)";

	public NameValidator() {
		super("[a-zA-Z0-9_]+([\\.-][a-zA-Z0-9_]+)*", true, ERROR_MESSAGE);
	}

}

==> vaadin-jmxconfiggenerator-24.0.0-20181130.235546-45-sources.jar: org/opennms/features/vaadin/jmxconfiggenerator/ui/mbeans/validation/NameValidator.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2011-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.vaadin.jmxconfiggenerator.ui.mbeans.validation;

import com.vaadin.v7.data.validator.RegexpValidator;

/**
 *
 * @author Markus von Rüden
 */
public class NameValidator extends RegexpValidator {

	protected static final String ERROR_MESSAGE = "You must specify a valid name. Allowed characters: (a-z, A-Z, 0-9,. , _)";

	public NameValidator() {
		super("[a-zA-Z0-9_]+([\\.-][a-zA-Z0-9_]+)*", true, ERROR_MESSAGE);
	}

}
